..
    This file is part of Invenio.
    Copyright (C) 2015 CERN.

    Invenio is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Invenio is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Invenio; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA 02111-1307, USA.

    In applying this license, CERN does not
    waive the privileges and immunities granted to it by virtue of its status
    as an Intergovernmental Organization or submit itself to any jurisdiction.

Authors
=======

Invenio module that adds record commenting feature.

- Adrian Pawel Baran <adrian.pawel.baran@cern.ch>
- Adrian-Tudor Panescu <adrian.tudor.panescu@cern.ch>
- Alberto <alberto.rodriguez.peon@cern.ch>
- Benoit Thiell <bthiell@cfa.harvard.edu>
- Björn Oltmanns <bjoern.oltmanns@gmail.com>
- Dimitrios Semitsoglou-Tsiapos <dsemitso@cern.ch>
- Eirini Psallida <eirini.psallida@cern.ch>
- Esteban J. G. Gabancho <egabancho@gmail.com>
- Glenn Gard <glenng4@aol.com>
- Gregory Favre <gregory.favre@cern.ch>
- Guillaume Lastecoueres <PX9e@gmx.fr>
- Jake Cowton <jake.calum.cowton@cern.ch>
- Javier Martin <javier.martin.montull@cern.ch>
- Jerome Caffaro <jerome.caffaro@cern.ch>
- Jiri Kuncar <jiri.kuncar@cern.ch>
- Joe Blaylock <jrbl@slac.stanford.edu>
- Kamil Neczaj <kneczaj@gmail.com>
- Lars Holm Nielsen <lars.holm.nielsen@cern.ch>
- Leonardo Rossi <leonardo.r@cern.ch>
- Ludmila Marian <ludmila.marian@gmail.com>
- Nicholas Robinson <nicholas.robinson@cern.ch>
- Olivier Canévet <olivier.canevet@cern.ch>
- Paulo Cabral <paulo.cabral@cern.ch>
- Peter Halliday <phalliday@cornell.edu>
- Raquel Jimenez Encinar <raquel.jimenez.encinar@cern.ch>
- Samuele Kaplun <samuele.kaplun@cern.ch>
- Tibor Simko <tibor.simko@cern.ch>
- Yoan Blanc <yoan.blanc@cern.ch>
